/v1/qemu/binaries — GNS3 1.3.dev1 documentation

### Navigation

- index
- next |
- previous |
- GNS3 1.3.dev1 documentation »
- Qemu »

# /v1/qemu/binaries

Contents

- /v1/qemu/binaries
  - GET /v1/qemu/binaries
    - Response status codes

## GET /v1/qemu/binaries

Get a list of available Qemu binaries

### Response status codes

- 200: Success
- 400: Invalid request
- 404: Instance doesn’t exist

### Navigation

- index
- next |
- previous |
- GNS3 1.3.dev1 documentation »
- Qemu »